Package: OmaDB
Title: R wrapper for the OMA REST API
Version: 2.28.0
Author: Klara Kaleb 
Maintainer: Klara Kaleb <klara.kaleb18@ic.ac.uk>, Adrian Altenhoff <adrian.altenhoff@inf.ethz.ch>
Description: A package for the orthology prediction data download from OMA database.
Depends: R (>= 3.5), httr (>= 1.2.1), plyr(>= 1.8.4)
Imports: utils, ape, Biostrings, GenomicRanges, IRanges, methods,
        topGO, jsonlite
URL: https://github.com/DessimozLab/OmaDB
BugReports: https://github.com/DessimozLab/OmaDB/issues
Encoding: UTF-8
License: GPL-3
LazyData: true
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
biocViews: Software, ComparativeGenomics, FunctionalGenomics, Genetics,
        Annotation, GO, FunctionalPrediction
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/OmaDB
git_branch: RELEASE_3_23
git_last_commit: de716ca
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 21:15:50 UTC; biocbuild
Built: R 4.6.0; ; 2026-05-01 03:08:37 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method("$",omadb_obj)
export(annotateSequence)
export(formatTopGO)
export(getAnnotation)
export(getAttribute)
export(getData)
export(getGenome)
export(getGenomeAlignment)
export(getGenomePairs)
export(getHOG)
export(getLocus)
export(getOMAGroup)
export(getObjectAttributes)
export(getProtein)
export(getTaxonomy)
export(getTopGO)
export(getTree)
export(getVersion)
export(getXref)
export(mapSequence)
export(resolveURL)
export(searchProtein)
export(setAPI)
import(ape)
import(httr)
import(plyr)
import(topGO)
importFrom(Biostrings,AAString)
importFrom(Biostrings,DNAString)
importFrom(GenomicRanges,GRanges)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(IRanges,IRanges)
importFrom(ape,read.tree)
importFrom(methods,new)
importFrom(topGO,annFUN.gene2GO)
importFrom(utils,URLencode)
importFrom(utils,packageVersion)

# OmaDB: R wrapper for the OMA REST API

R package providing access to the data in the OMA browser, using the REST API. As such, it requires a stable internet connection to operate. We also provide a similar _wrapper for python (https://github.com/DessimozLab/pyOmaDB)_.

An notebook containing examples of how to use the package is available <a href="https://github.com/DessimozLab/omadb/blob/master/manuscript_examples.ipynb">here</a>.

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/DessimozLab/omadb/master?filepath=manuscript_examples.ipynb)

## Citation
If you use our package in your work, please consider citing:

_Kaleb K, Warwick Vesztrocy A, Altenhoff A and Dessimoz C. Expanding the Orthologous Matrix (OMA) programmatic interfaces: REST API and the OmaDB packages for R and Python. F1000Research 2019, 8:42
(https://doi.org/10.12688/f1000research.17548.2)_

## Installation

The package is available via Bioconductor (https://bioconductor.org) and can be installed as follows:

```
if (!requireNamespace("BiocManager"))
    install.packages("BiocManager")
BiocManager::install('OmaDB')

#load the package
library(OmaDB)

```

Note that the v2.0 of the package requires R version >= 3.6 and Bioconductor version >=3.9. 

The latest version of the OmaDB package can also be directly installed from the github repository as below:

```
install.packages('devtools')
library(devtools)
install_github('dessimozlab/omadb')
```


## License

OmaDB is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

OmaDB is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.
You should have received a copy of the GNU Lesser General Public License
along with OmaDB.  If not, see <http://www.gnu.org/licenses/>.

#' Retrieve an OMA Group from the OMA Browser
#'
#' This function obtains an OMA Group from the OMA Browser database. An OMA Group
#' is defined to be a clique of proteins that are all orthologous to each other,
#' i.e. they are all related through speciation events only. An OMA Group can thus
#' by definition not contain any inparalogs. It is a very stringent orthology
#' grouping approach.
#' OMA Groups are mostly useful to infer phylogenetic species tree where they
#' can be used as marker genes.
#'
#' Retrieving an OMA Group can be done using a group nr as id, its fingerprint
#' (a 7mer AA sequence which is unique to proteins in that group), a member
#' protein id or any sequence pattern that is unique to the group.
#'
#' @param id An identifier for the group. See above for possible types of IDs.
#' @param attribute an extra attribute to be returned (close_groups)
#' @return an object containing the JSON keys as attributes or a dataframe
#' @export
#' @examples
#' getOMAGroup(id='58')
#' getOMAGroup(id='P12345')
#' getOMAGroup(id='NNRRGRI')
#' getOMAGroup(id='58', attribute='close_groups')

getOMAGroup <- function(id, attribute = NULL) {

    if (!is.null(attribute) && !(attribute %in% c("close_groups"))) {
        stop("You must provide a valid attribute.")
    }
    url <- urlGenerator(endpoint = "group", id = id, detail = attribute)
    return(requestFactory(url))
}

#' Get the CrossReferences in the OMA database for a pattern
#'
#' The function to list all the crossreferences that match a certain defined pattern.
#'
#' @param pattern the pattern to query the OMA database with - needs to be at least 3 characters long
#' @return a data.frame containing information on the cross references for a given pattern
#' @export
#' @examples
#' searchProtein(pattern='MAL')

searchProtein <- function(pattern) {
    url <- urlGenerator(endpoint = "xref", search = pattern)
    return(requestFactory(url))
}

#' Format the GO annotations data
#'
#' The function to create a list of GO annotations that is compatible with topGO from protein objects in roma
#'
#' @param geneList the list of OmaDB protein objects or a dataframe of ontologies to be included in the analysis - this is where the GO annotations are extracted from.
#' @param format format for the data to be returned in - either 'GO2geneID' or 'geneID2GO'
#' @return a list containing the GO2geneID or geneID2GO information
#' @export
#' @examples
#' geneList = list(getProtein(id='YEAST01'),getProtein(id='YEAST03'))
#' annotations = formatTopGO(geneList,format='geneID2GO')



formatTopGO <- function(geneList, format) {

    if (!(format %in% list("GO2geneID", "geneID2GO"))) {
        stop("Invalid format. Must be either 'GO2geneID' or 'geneID2GO'")
    }

    if (class(geneList) == "data.frame") {

        geneNames <- unique(geneList$entry_nr)
        geneListFormatted <- lapply(geneNames, function(x) geneList[geneList$entry_nr ==
            x, ]$GO_term)

        names(geneListFormatted) <- geneNames

        geneID2GO <- geneListFormatted

    } else {
        geneID2GO <- lapply(geneList, FUN = function(protein) {

            if (startsWith(protein[["gene_ontology"]], "https://")) {
                annotation <- protein$gene_ontology

                if (class(annotation) == "data.frame") {
                  unlist(as.list(annotation[["GO_term"]]))
                } else {
                  annotation
                }
            } else {
                if (class(annotation) == "data.frame") {
                  unlist(as.list(protein[["gene_ontology"]][["GO_term"]]))
                } else {
                  annotation
                }
            }
        })

        names(geneID2GO) <- lapply(geneList, FUN = function(protein) {
            protein$omaid
        })

    }


    if (format == "geneID2GO") {
        return(geneID2GO)
    }
    if (format == "GO2geneID") {
        return(topGO::inverseList(geneID2GO))
    }
}

#' Get the Object Attributes
#'
#' The function to obtain the attributes and their data types for the object created.
#'
#' @param obj the object of interest
#' @return an list of object attributes and their data classes
#' @export
#' @examples
#' attributes = getObjectAttributes(getOMAGroup(id ='YEAST58'))


getObjectAttributes <- function(obj) {
    for (name in attributes(obj)$names) {

        class_name <- class(obj[[name]])

        if (class_name == "character" && startsWith(obj[[name]], "https://")) {
            class_name <- "URL"

        }

        print(paste(name, ":", class_name))

    }
}

#' Get the value for the Object Attribute
#'
#' The function to obtain the value for an object attribute.
#'
#' @param obj the object of interest
#' @param attribute the attribute of interest
#' @return an value for a given object attribute
#' @export
#' @examples
#' members = getAttribute(getOMAGroup(id ='YEAST58'),'members')


getAttribute <- function(obj, attribute) {

    if (is.character(obj[[attribute]]) && grepl("https://", obj[[attribute]])) {

        value <- requestFactory(obj[[attribute]])
        obj_name <- deparse(substitute(obj))
        set_new_val(obj, attribute) <- value
        assign(obj_name, obj, envir = .GlobalEnv)

    }

    return(obj[[attribute]])
}

## ----warning=FALSE, message=FALSE---------------------------------------------
library(OmaDB)

load('../data/hog.rda')

print(hog)

getObjectAttributes(hog)

hog_id = getAttribute(hog,'hog_id')

parent_hogs = getAttribute(hog,'parent_hogs')

dim(parent_hogs)

parent_hog_id = parent_hogs[[hog_id]]

children_hogs = getAttribute(hog,'children_hogs')

children_hogs

child_hog_ids  = children_hogs[['hog_id']]

#' Get the topGO Object function
#'
#' The function to create a topGO object containing the GO annotations for the given protein list.
#'
#' @param annotations list of GO annoatations obtained from the formatTopGO()
#' @param foregroundGenes List of identifiers for the foreground genes
#' @param format Format for the data to be returned in - either 'GO2geneID' or 'geneID2GO'
#' @param ontology The ontology for which the enrichment should be done. This
#'        parameter is passed directly to the topGOdata constructor.
#' @return topGO object
#' @export
#' @import topGO
#' @importFrom topGO annFUN.gene2GO
#' @importFrom methods new
#' @examples
#' geneList = list(getProtein(id='YEAST58'),getProtein(id='YEAST00059'))
#' annotations = formatTopGO(geneList,format='geneID2GO')
#' library(topGO)
#' getTopGO(annotations, foregroundGenes = list('YEAST00058'), format = 'geneID2GO', ontology = 'BP')

getTopGO <- function(annotations, format, foregroundGenes, ontology) {

    if (missing(ontology)) {
        stop("You must provide the ontology for which the enrichment should be done.")
    }

    if (missing(annotations) || class(annotations) != "list") {
        stop("You must provide a valid list of annotations.")
    }

    if (missing(format) || !(format %in% list("geneID2GO", "GO2geneID"))) {
        stop("You must provide a valid annotations format.")
    }

    if (missing(foregroundGenes)) {
        stop("You must provide a valid list of genes of interest.")
    }

    if (class(foregroundGenes) == "data.frame") {
        foregroundGenes <- foregroundGenes[["omaid"]]
    }

    geneNames <- names(annotations)
    geneList <- factor(as.integer(geneNames %in% foregroundGenes))
    names(geneList) <- geneNames

    if (format == "geneID2GO") {
        GOdata <- new("topGOdata", ontology = ontology, allGenes = geneList, annot = topGO::annFUN.gene2GO,
            gene2GO = annotations)
    }
    if (format == "GO2geneID") {
        GOdata <- new("topGOdata", ontology = ontology, allGenes = geneList, annot = topGO::annFUN.GO2genes,
            GO2gene = annotations)
    }
    return(GOdata)
}

#' Get the Taxonomic tree function
#'
#' The function to obtain the taxonomic tree from the database in the newick format that can be plugged into phylo.io for visualisation.
#'
#' @param root optional parameter, the root of the node of interest
#' @param members optional parameter, list of member ncbi taxon or UniProt IDs that should be included in the induced taxonomy.
#' @param newick optional parameter, boolean default set to TRUE
#' @return an object containing the JSON keys as attributes
#' @export
#' @examples
#' getTaxonomy()
#' getTaxonomy(members='YEAST,ASHGO')
#' getTaxonomy(root='Alveolata')

getTaxonomy <- function(root = NULL, members = NULL, newick = TRUE) {
    if (!is.logical(newick)) {
        stop("newick parameter must be a logical value")
    }
    format <- if (newick)
        "newick" else NULL
    url <- urlGenerator(endpoint = "taxonomy", id = root, type = format, members = members)
    return(requestFactory(url))
}

#' @importFrom utils URLencode packageVersion
#' @import httr
#' @import plyr
#' @import ape
#' @importFrom  Biostrings AAString
#' @importFrom Biostrings DNAString
#' @importFrom GenomicRanges GRanges
#' @importFrom GenomicRanges makeGRangesFromDataFrame
#' @importFrom IRanges IRanges


pkg.env <- new.env()
pkg.env$API_default_url <- "https://omabrowser.org/api/"
pkg.env$API_url <- pkg.env$API_default_url
pkg.env$API_version <- "1.6"
pkg.env$user_agent <- paste0("r-omadb/", packageVersion("OmaDB"))


urlGenerator <- function(endpoint, id = NULL, detail = NULL, ...) {
    url_prefix <- paste0(pkg.env$API_url, tolower(endpoint), "/")
    if (!is.null(id)) {
        id <- paste0(utils::URLencode(as.character(id)), "/")
    }
    if (!is.null(detail)) {
        detail <- paste0(as.character(detail), "/")
    }
    base_url <- paste0(url_prefix, id, detail)

    qargs <- unlist(list(...))
    if (length(qargs) == 0) {
        return(base_url)
    }

    # remove all qargs that are NULL
    qargs[sapply(qargs, is.null)] <- NULL
    if (length(qargs) == 0) {
        return(base_url)
    }

    qarg_vals <- lapply(lapply(qargs, as.character), URLencode)
    qargs <- mapply(paste, names(qargs), qarg_vals, sep = "=", USE.NAMES = F)
    query_param <- paste(qargs, collapse = "&")
    final_url <- paste(base_url, query_param, sep = "?")
    return(final_url)
}


simpleRequest <- function(url, body = NULL) {
    response <- load_url(url, body = body)
    if (!is.null(response)) {
        content_list <- httr::content(response, as = "parsed")
        column_names <- names(content_list)
        return(objectFactory(column_names, content_list))
    }
    return(NULL)
}

load_url <- function(url, body = NULL) {
    count <- 0
    accept_header = paste0("application/json; version=", pkg.env$API_version)
    while (count < 3) {
        response <- tryCatch(if (!is.null(body)) {
            httr::POST(url, body = body, encode = "raw", httr::accept(accept_header),
                httr::content_type("application/json"), httr::user_agent(pkg.env$user_agent))
        } else {
            httr::GET(url, httr::accept(accept_header), httr::content_type("application/json"),
                httr::user_agent(pkg.env$user_agent))
        }, error = function(cond) {
            Sys.sleep(0.5)
            return(NULL)
        }, warning = function(cond) {
            message(cond)
            return(NULL)
        })

        if (is.null(response)) {
            count <- count + 1
            next
        }

        if (response$status_code < 500) {
            break
        }
        message(sprintf("Request failed with server error %d. retry in %d secs",
            response$status_code, 2^count))
        Sys.sleep(2^count)
        count <- count + 1
    }

    if (is.null(response)) {
        message(sprintf("Cannot resolve '%s'. Please connect to the internet", url))
        return(NULL)
    }

    tryCatch({
        httr::stop_for_status(response)
        # request worked out
        return(response)
    }, http_400 = function(cond) {
        reason <- httr::content(response, as = "parsed")
        if (!is.null(reason)) {
            cond$message <- paste0(cond$message, " Reason: ", reason$detail)
        }
        message(cond)
        return(NULL)
    }, error = function(cond) {
        cond$message <- paste0("Request to ", url, " failed:\n", cond$message, "\n")
        message(cond)
        return(NULL)
    }, warning = function(cond) {
        warning(cond)
        return(NULL)
    })
}

filterNullData <- function(column_names, content_list){
   list_of_vars <- lapply(column_names, FUN = function(name){
     c <- content_list[[name]]
     if (is.null(c)){
       return(NULL)
     }
     if (class(c) == "list"){
       return(filterNullData(names(c), c))
     }
     return(c)
   })
   names(list_of_vars) <- column_names
   list_of_vars[sapply(list_of_vars, is.null)] <- NULL
   value <- list_of_vars
   return(value)
}


objectFactory <- function(column_names, content_list) {
    list_of_variables <- lapply(column_names, FUN = function(name) {
        content <- content_list[[name]]
        if (is.null(content)) {
            content == ""
        }
        if (class(content) == "list" && name %in% c("children_hogs", "alternative_levels",
            "parent_hogs")) {
            # delete these fields
            return(NULL)
        }

        if (class(content) == "list" && length(content) != 0 && name != "locus" &&
            name != "chromosomes") {
            if (is.null(names(content))) {
                formatData(content)  # if list, make into DF.
            }
        } else if (name == "chromosomes") {
            formatData(content)
        } else if (name == "locus") {
            GenomicRanges::GRanges(seqnames = content_list[["omaid"]], ranges = IRanges::IRanges(content$start,
                content$end), strand = content$strand)
        } else if (name == "sequence") {
            Biostrings::AAString(content)
        } else if (name == "cdna") {
            content <- gsub("X", "N", content)
            Biostrings::DNAString(content)
        } else {
            content
        }
    })

    names(list_of_variables) <- column_names
    list_of_variables[sapply(list_of_variables, is.null)] <- NULL
    value <- list_of_variables
    class(value) <- "omadb_obj"
    return(value)
}

largeRequestFactory <- function(url, n, per_page, body = NULL) {
    if (!is.null(body)) {
        response_list <- lapply(body, FUN = function(x) {
            load_url(url, body = x)
        })
    } else {
        n_requests <- ceiling(as.numeric(n) / per_page)
        prefix <- if (substr(url, nchar(url), nchar(url)) == "/")
            "?per_page=" else "&per_page="
        url_list <- list()
        for (i in seq_along(1:n_requests)) {
            url_list[[i]] <- paste0(url, prefix, per_page, "&page=", i)
        }
        response_list <- lapply(url_list, FUN = function(x) {
            load_url(x, body)
        })
    }

    json_list <- lapply(response_list, FUN = function(x) {
        httr::content(x, as = "parsed")
    })
    content_list <- do.call("c", json_list)
    return(content_list)
}

extractdata <- function(content_list) {
    column_names <- names(content_list)
    if (is.null(column_names)) {
        # this is due to /hog/ formatting in the API
        if (length(content_list) == 0) {
            return(content_list)
        }

        if (length(content_list) == 1) {
            column_names <- names(content_list[[1]])
            content_list <- content_list[[1]]
            return(objectFactory(column_names, content_list))

        } else if (length(content_list) > 1) {
            return(formatData(content_list))
        }
    } else {
        return(objectFactory(column_names, content_list))
    }
}



requestFactory <- function(url, body = NULL, per_page = 5000, page = NULL) {
    if (!is.null(body)) {
        return(largeRequestFactory(url, body = body))
    }

    # sep for per_page query params is either ? or & depending if
    # no query param so far or not
    sep <- if (substr(url, nchar(url), nchar(url)) == "/")
        "?" else "&"
    qq <- paste0("per_page=", per_page, "&page=", if (is.null(page))
        1 else page)
    first_url <- paste(url, qq, sep = sep)

    response <- load_url(first_url, body = body)
    if (is.null(response)) {
        return(NULL)
    }

    content_list <- httr::content(response, as = "parsed")
    n_items <- httr::headers(response)[["x-total-count"]]
    if (is.null(page) && !is.null(n_items)) {
        # if we need all data and data is pageinated, check if we already have all data.
        # if not, retrieve in parallel
        nr_elem <- length(content_list)
        n_items <- as.numeric(n_items)
        if (nr_elem < n_items) {
            content_list <- largeRequestFactory(url, n_items, per_page)
        }
    }
    return(extractdata(content_list))
}



formatData <- function(data) {
    # flatten chromosomes in genome so that GRanges object can form
    if ("entry_ranges" %in% names(data[[1]])) {
        for (i in seq_along(data)) {
            data[[i]][["entry_ranges.1"]] <- data[[i]]["entry_ranges"][[1]][[1]][[1]]
            data[[i]][["entry_ranges.2"]] <- data[[i]]["entry_ranges"][[1]][[1]][[2]]
            data[[i]][["entry_ranges"]] <- NULL
        }
    } else if ("sequence" %in% names(data[[1]]) || "alternative_levels" %in% names(data[[1]])) {
        # to ensure bulk retrieve nor hog-info does not form a df
        for (i in seq_along(data)) {
            data[[i]] <- objectFactory(names(data[[i]]), data[[i]])
        }
        return(data)
    } else if ("entry_1" %in% names(data[[1]])){
      # we are dealing with an getGenomePairs. Ensure no NULL values
      for (i in seq_along(data)){
        data[[i]] <- filterNullData(names(data[[i]]), data[[i]])
      }
    }

    dfs <- lapply(data, data.frame, stringsAsFactors = FALSE)
    data <- plyr::rbind.fill(dfs)
    return(data)
}

#' Resolve URLs automatically when accessed
#'
#' The function to obtain further information from a given url.
#'
#' @param x object
#' @param name attribute
#' @return API response behind the URL
#' @export

"$.omadb_obj" <- function(x, name) {
    if (is.character(x[[name]]) && grepl("https://", x[[name]])) {
        value <- requestFactory(x[[name]])
        obj_name <- deparse(substitute(x))
        set_new_val(x, name) <- value
        assign(obj_name, x, envir = .GlobalEnv)
    }
    return(x[[name]])
}

"set_new_val<-" <- function(x, name, value) {
    x[[name]] <- value
    x
}


#' Set the url to the OMA Browser API
#'
#' Function to set the base url to the OMA Browser API. If no url is
#' specified, the default OMA Browser API url is used.
#'
#' @param url Base url to the API
#' @export

setAPI <- function(url) {
    if (missing(url)) {
        url <- pkg.env$API_default_url
    }
    if (substr(url, nchar(url), nchar(url)) != "/") {
        url <- paste0(url, "/")
    }
    pkg.env$API_url <- url
}


#' Load data for a given url from the OMA Browser API.
#'
#' This function is usualy not needed by users. In most circumstances
#' an attribute containing a URL is automatically loaded when accessed.
#' However, in case the data is transformed into a dataframe, this will
#' no longer be true, in which case one can access the data behind this
#' attribute using this function.
#'
#' @param url The url of interest
#' @return a data.frame containing the information behind an URL
#' @export
#' @examples
#' resolveURL('http://omabrowser.org/api/protein/YEAST58/gene_ontology/')
resolveURL <- function(url) {
    return(requestFactory(url))
}

#' Retrieve a genome from the OMA Browser database
#'
#' This function obtains the basic information for one specific genome available
#' on the OMA Browser, or - if no id is provided - a dataframe with all available
#' genomes.
#'
#' Ids can be either the scientific name of a species, the NCBI taxonomy id or
#' the UniProtKB mnemonic species code.
#'
#' The optional argument attribute can be used to directly load the proteins
#' belonging to the genome. Alternatively, you can access the proteins attribute
#' of the result which will transparently load the proteins from the OMA Browser.
#'
#' @param id A genome identifier. By default, all available genomes will be returned.
#' @param attribute An extra attribute to be returned (proteins)
#' @return an object containing the JSON keys as attributes or a dataframe
#' @export
#' @examples
#' getGenome()
#' getGenome(id='HUMAN')
#' getGenome(id=9606)
#' getGenome(id='YEAST',attribute='proteins')

getGenome <- function(id = NULL, attribute = NULL) {

    if (!is.null(attribute) && !(attribute %in% c("proteins"))) {
        stop("You must provide a valid attribute.")
    }

    url <- urlGenerator(endpoint = "genome", id = id, detail = attribute)

    return(requestFactory(url))
}

#' Retrieves the pairwise relations among two genomes
#'
#' This function retrieves the pairwise relations among two genomes from
#' the OMA Browser database. The relations are orthologs in case the 
#' genomes are different and "close paralogs" and "homoeologs" in case 
#' they are the same.
#' 
#' By using the parameters chr1 and chr2, one can limit the relations 
#' to a certain chromosome for one or both genomes. The id of the 
#' chromosome corresponds to the chromosome ids from the 
#' \code{\link{getGenome}} result.
#' 
#' The rel_type parameter further limits the returned relations to a
#' specific subtype of orthologs (i.e. "1:1", "1:n", "m:1", "m:n") or 
#' - within a genome to either "close paralogs" or "homeologs".
#'
#' @param genome_id1 an identifier for the first genome, which can be either its taxon id or UniProt species code
#' @param genome_id2 an an identifier for the second genome, which can be either its taxon id or UniProt species code
#' @param chr1 the chromosome of interest for the first genome
#' @param chr2 the chromosome of interest for the second genome
#' @param rel_type the pairs relationship type
#' @param ... qwargs
#' @return a dataframe containing information about both the entries in the orthologous pair and their relationship
#' @export
#' @examples
#' getGenomePairs(genome_id1='YEAST',genome_id2='ASHGO')

getGenomePairs <- function(genome_id1, genome_id2, chr1 = NULL, chr2 = NULL, rel_type = NULL,
    ...) {
    if (missing(genome_id1) || missing(genome_id2)) {
        stop("You must provide IDs for both genomes.")
    }
    if (!is.null(rel_type)) {
        if (!(rel_type %in% c("1:1", "1:n", "m:n", "m:1", "close paralog", "homeolog"))) {
            stop("You must enter a valid relationship type.")
        }
    }

    url <- urlGenerator(endpoint = "pairs", id = genome_id1, detail = genome_id2,
        chr1 = chr1, chr2 = chr2, rel_type = rel_type)

    return(requestFactory(url, ...))
}

#' Get the Tree Object
#'
#' A convenience function to obtain a tree object from newick tree,
#' essentially wraps read.tree from the ape package.
#'
#' @param newick The newick tree to be instantiated.
#' @return a tree object
#' @export
#' @importFrom ape read.tree
#' @examples
#' taxonomy = getTaxonomy(root='Alveolata')
#' getTree(newick=taxonomy$newick)


getTree <- function(newick) {
    if (class(newick) == "list") {
        newick <- newick$newick
    }
    return(ape::read.tree(text = newick))
}

#' @title Deprecated functions in package \pkg{OmaDB}.
#' @description These functions are provided for compatibility with
#' older versions of \pkg{OmaDB} only, and will be defunct at the
#' next release.
#'
#' @details The following functions are deprecated and will be
#' made defunct; use the replacement indicated below:
#'
#' @name OmaDB-deprecated
#' @keywords internal
NULL



#' Get the CrossReferences in the OMA database for a pattern
#'
#' This function is should no longer be used. Use instead \code{\link{searchProtein}}.
#'
#' @param pattern the pattern to query the OMA database with - needs to be at least 3 characters long
#' @return a data.frame containing information on the cross references for a given pattern
#'
#' @templateVar fun getXref
#' @template template-depr_fun
NULL

#' @templateVar old getXref
#' @templateVar new searchProtein
#' @template template-depr_pkg
#'
#' @export
getXref <- function(pattern) {
    .Deprecated("searchProtein")
    return(searchProtein(pattern))
}

#' Get GO annotation for a sequence Function
#'
#' This function should no longer be used. Use instead \code{\link{annotateSequence}}.
#'
#' @param query the sequence to be annotated, it can be either a string or an AAString object from the Biostrings package
#' @return a data.frame containg the GO annotaition information linked to the query sequence
#'
#' @templateVar fun getAnnotation
#' @template template-depr_fun
NULL

#' @templateVar old getAnnotation
#' @templateVar new annotateSequence
#' @template template-depr_pkg
#' @export
getAnnotation <- function(query) {
    .Deprecated("annotateSequence")
    return(annotateSequence(query))
}

#' Get Whole Genome Alignment Function
#'
#' This function should no longer be used. Use instaed \code{\link{getGenomePairs}}.
#'
#' @param genome_id1 an identifier for the first genome, which can be either its taxon id or UniProt species code
#' @param genome_id2 an an identifier for the second genome, which can be either its taxon id or UniProt species code
#' @param chr1 the chromosome of interest for the first genome
#' @param chr2 the chromosome of interest for the second genome
#' @param rel_type the pairs relationship type
#' @param per_page the number of instances to be returned or 'all'. default is set to a 100.
#' @return a dataframe containing information about both the entries in the orthologous pair and their relationship
#'
#' @templateVar fun getGenomeAlignment
#' @template template-depr_fun
NULL

#' @templateVar old getGenomeAlignment
#' @templateVar new getGenomePairs
#' @template template-depr_pkg
#'
#' @export
getGenomeAlignment <- function(genome1, genome2, chr1 = NULL, chr2 = NULL, rel_type = NULL) {
    .Deprecated("getGenomePair")
    return(getGenomePairs(genome1, genome2, chr1, chr2, rel_type))
}


#' Get the Data Function
#'
#' The function to obtain the information available for a single entry in the datase.
#' This function should no longer be used. It has been divided into several functions:
#' Use the following functions instead.
#' \itemize{
#'   \item \code{\link{getProtein}} to obtain proteins (former \code{type='protein'})
#'   \item \code{\link{getGenome}} to obtain genomes (former \code{type='genome'})
#'   \item \code{\link{getOMAGroup}} to obtain genomes (former \code{type='group'})
#' }
#'
#' @param type the type for the entry to be returned - either protein, genome or group
#' @param id an identifier for the entry to be returned. For more information, see the 'Get started with OmaDB' vignette.
#' @param attribute an extra attribute
#' @return an object containing the JSON keys as attributes
#'
#' @templateVar fun getData
#' @template template-depr_fun
NULL

#' @templateVar old getData
#' @templateVar new getProtein}, \link{getGenome}, \link{getOMAGroup
#' @template template-depr_pkg
#'
#' @export
getData <- function(type, id, attribute = NULL) {
    if (type == "group") {
        .Deprecated("getOMAGroup")
        return(getOMAGroup(id, attribute))
    } else if (type == "genome") {
        .Deprecated("getGenome")
        return(getGenome(id, attribute))
    } else if (type == "protein") {
        .Deprecated("getProtein")
        return(getProtein(id, attribute))
    } else {
        .Deprecated("getProtein")
        return(NULL)
    }
}

#' Get the API and database version function
#'
#' The function to obtain the API and database version that the package is using.
#'
#' @return S3 object
#' @export
#' @examples
#' getVersion()


getVersion <- function() {
    url <- urlGenerator(endpoint = "version")
    return(requestFactory(url))
}

#' Map GO annotation to a sequence that is not available in the OMA Browser
#'
#' This function obtain Gene Ontology annotation for a given sequence that
#' does not need to exist in the OMA Browser so far. The query sequence will
#' analysed and a fast homology detection approach based on kmers will be used
#' to detect the closest sequences in OMA. GO annotations for these top hits
#' will be used to annotated the query sequence.
#'
#' @param query the sequence to be annotated, it can be either a string or an
#'        AAString object from the Biostrings package
#' @return a data.frame containing the the GO annotation information of the
#'        most similar protein to the query sequence
#' @export
#' @examples
#' annotateSequence(query='MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHERRFIEINTDGEPQREYDSLQQSTEHLATDLAKRTFTVLSYNTLCQHYATPKMYRYTPSWALSWDYRRNKLKEQILSYDSDLLCLQEVESKTFEEYWVPLLDKHGYTGIFHAKARAKTMHSKDSKKVDGCCIFFKRDQFKLITKDAMDFSGAWMKHKKFQRTEDYLNRAMNKDNVALFLKLQHIPSGDTIWAVTTHLHWDPKFNDVKTFQVGVLLDHLETLLKEETSHNFRQDIKKFPVLICGDFNSYINSAVYELINTGRVQIHQEGNGRDFGYMSEKNFSHNLALKSSYNCIGELPFTNFTPSFTDVIDYIWFSTHALRVRGLLGEVDPEYVSKFIGFPNDKFPSDHIPLLARFEFMKTNTGSKKV')

annotateSequence <- function(query) {
    if (missing(query)) {
        stop("You must provide a sequence to query.")
    }
    if (class(query) == "AAString") {
        query <- as.character(query)
    }

    url <- urlGenerator(endpoint = "function", query = query)
    return(requestFactory(url))
}

#' Map the Protein Sequence Function
#'
#' The function to identify a sequence.
#'
#' @param query the sequence to be searched, it can be either a string or an AAString object from the Biostrings package
#' @param search argument to choose search strategy. Can be set to 'exact', 'approximate' or 'mixed'. Defaults to 'mixed', meaning first tries to find exact match. If no target can be found, uses approximate search strategy to identify query sequence in database.
#' @param full_length a boolean indicating whether or not for exact matches, the query sequence must be matching the full target sequence. By default, a partial exact match is also reported as exact match.
#' @return a data.frame containing the information of matches for the query sequence
#' @export
#' @examples
#' mapSequence(query='MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHERRFIEINTDGEPQREYDSLQQSTEHLATDLAKRTFTVLSYNTLCQHYATPKMYRYTPSWALSWDYRRNKLKEQILSYDSDLLCLQEVESKTFEEYWVPLLDKHGYTGIFHAKARAKTMHSKDSKKVDGCCIFFKRDQFKLITKDAMDFSGAWMKHKKFQRTEDYLNRAMNKDNVALFLKLQHIPSGDTIWAVTTHLHWDPKFNDVKTFQVGVLLDHLETLLKEETSHNFRQDIKKFPVLICGDFNSYINSAVYELINTGRVQIHQEGNGRDFGYMSEKNFSHNLALKSSYNCIGELPFTNFTPSFTDVIDYIWFSTHALRVRGLLGEVDPEYVSKFIGFPNDKFPSDHIPLLARFEFMKTNTGSKKV')
#' mapSequence(search='mixed',query='NKLLQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHERRFIEINTDGEPQREYDSLQQSTEHLATDLAKRTFTVLSYNTLCQHYATPKMYRYTPSWALSWDYRRNKLKEQILSYDSDLLCLQEVESKTFEEYWVPLLDKHGYTGIFHAKARAKTMHSKDSKKVDGCCIFFKRDQFKLITKDAMDFSGAWMKHKKFQRTEDYLNRAMNKDNVALFLKLQHIPSGDTIWAVTTHLHWDPKFNDVKTFQVGVLLDHLETLLKEETSHNFRQDIKKFPVLICGDFNSYINSAVYELINTGRVQIHQEGNGRDFGYMSEKNFSHNLALKSSYNCIGELPFTNFTPSFTDVIDYIWFSTHALRVRGLLGEVDPEYVSKFIGFPNDKFPSDHIPLLARFEFMKTNTGSKKV')



mapSequence <- function(query, search = NULL, full_length = FALSE) {
    if (missing(query)) {
        stop("You must provide a sequence to query.")
    }
    if (!is.null(search)) {
        search <- tolower(search)
        search_values <- c("approximate", "exact", "mixed")
        if (!search %in% search_values) {
            stop("search parameter invalid. Must be one of 'approximate', 'exact', 'mixed'")
        }
    }

    if (class(query) == "AAString") {
        query <- as.character(query)
    }
    url <- urlGenerator(endpoint = "sequence", query = query, full_length = full_length,
        search = search)
    return(requestFactory(url))
}

## ----warning=FALSE, message=FALSE---------------------------------------------
library(OmaDB)

xref = load('../data/xref.rda')

head(xref)


## ----warning=FALSE, message=FALSE---------------------------------------------

load('../data/pairs.rda')

head(pairs)


## ----warning=FALSE, message=FALSE---------------------------------------------

load('../data/group.rda')

object_attributes = getObjectAttributes(group)

group$fingerprint

getAttribute(group, 'fingerprint')

## template-depr_fun.r
#' @name <%= fun %>-deprecated
#' @usage <%= gsub("\n", "\n#' ", gsub("\u{A0}", " ", roxygen2:::wrapString(roxygen2:::function_usage(fun, formals(fun))))) %>
#' @seealso \code{\link{OmaDB-deprecated}}
#' @keywords internal

#' Retrieve a HOG from the OMA Browser
#'
#' The function retrieves a specific Hierarchical Orthologous Group (HOG) from
#' the OMA Browser database. A HOG is a set of genes that have all decendet from
#' a single ancestral gene at a specific taxonomic level.
#'
#' A HOG can be identified by its member proteins and a taxonomic level, or
#' a HOG ID. As a taxonomic level, you can use either 'root' to retrieve the
#' HOG at its deepest level, or the name of NCBI taxonomy level, or leave it
#' out in which case the deepest level that doesn't include a duplication node
#' is used.
#'
#' The function either returns a single hog object or a list of hog
#' objects. The later happens if the HOG ID you provide has already split into
#' several sub-hogs at the level you indicate.
#'
#' @param id an identifier for the HOG to be returned - either its HOG ID or a protein id.
#' @param level a specific level for the HOG to be restricted to. level can either be 'root', or the name of a taxonomic level that is part of the HOG, e.g. 'Fungi'. By default it will retrieve the depest level of the most specific subhog for the given ID.
#' @param members boolean that when set to TRUE returns a dataframe containg the protein members at a given hog level
#' @return an object containing HOG attributes, or a list of those
#' @export
#' @examples
#' getHOG(id = 'YEAST590')
#' getHOG(id = 'YEAST590', level='root')
#' getHOG(id = 'YEAST590', level='Saccharomycetaceae', members=TRUE)

getHOG <- function(id, level = NULL, members = FALSE) {

    if (class(members) != "logical") {
        stop("Members parameter is of type boolean.")
    }

    if (missing(id)) {
        stop("You must provide a valid HOG ID.")
    }

    if (!is.null(level) && class(level) == "integer") {
        stop("You must provide a valid identifier for a taxonomic level -
                it can only be idenitifed by its full capitalised name.")
    }

    memb <- if (members)
        "members" else NULL
    url <- urlGenerator(endpoint = "hog", id = id, detail = memb, level = level)
    return(requestFactory(url))
}

#' OmaDB: A package for the orthology prediction data download from OMA database.
#'
#' OmaDB is a wrapper for the REST API for the Orthologous MAtrix project (OMA)
#' which is a  database for the inference of orthologs among complete genomes.
#' For more details on the OMA project, see \url{https://omabrowser.org/}.
#'
#'
#' @section  OmaDB functions:
#' The package contains a range of functions that are used to query the
#' database. Some of the main functions are listed below:
#'
#' \itemize{
#'   \item getProtein()
#'   \item getHOG()
#'   \item getOMAGroup()
#'   \item getGenomePairs()
#'   \item getTaxonomy()
#'   \item mapSequence()
#'   \item annotateSequence()
#'   \item searchProtein()
#' }
#'
#' In addition to these, OmaDB features a range of functions that are used to
#' format the retrieved data into some commonly used Bioconductor objects using
#' packages such as GenomicRanges, Biostrings, topGO and ggtree. Some of them
#' are listed below:
#'
#' \itemize{
#'   \item formatTopGO()
#'   \item getGRanges()
#' }
#'
#' The above functions are described in more detail in the package vignette's
#' listed below:
#'
#'
#' \itemize{
#'   \item Get started with OmaDB
#'   \item Exploring Hierarchical orthologous groups with OmaDB
#'   \item Exploring Taxonomic trees with OmaDB
#'   \item Sequence Analysis with OmaDB
#' }
#'

"_PACKAGE"

## -----------------------------------------------------------------------------
 sequence = "MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHER"

## ----warning=FALSE, message=FALSE---------------------------------------------
library(OmaDB)

load('../data/sequence_map.rda')

getObjectAttributes(sequence_map)

targets = getAttribute(sequence_map,'targets')

length(targets) 

protein = targets[[1]][['entry_url']]


## ----warning=FALSE, message=FALSE---------------------------------------------

load('../data/sequence_annotation.rda')

sequence_annotation 

#' Get loci for a given list of proteins
#'
#' Function to obtain loci in genomic range format for a given list of proteins
#'
#' @param proteins the dataframe or a list of dataframes containing the protein data of interest. this can either be the members df or a list of protein ids.
#' @return genomic range object from the GenomicRanges package in Bioconductor
#' @export
#' @importFrom GenomicRanges makeGRangesFromDataFrame
#' @examples
#' loci = getLocus(proteins = getOMAGroup('YEAST58')['members'])

getLocus <- function(proteins) {

    # if a list of dataframes is given.
    if (class(proteins) == "list") {
        if (class(proteins[[1]]) == "data.frame") {

            df <- plyr::rbind.fill(proteins)

        } else {

            df <- getProtein(id = proteins, attribute = "locus")

        }

    }

    df$locus.strand[df$locus.strand == "1"] <- "+"
    df$locus.strand[df$locus.strand == "-1"] <- "-"

    grange <- GenomicRanges::makeGRangesFromDataFrame(df, start.field = "start",
        end.field = "end", seqnames.field = "omaid")

    return(grange)

}

#' Retrieve a protein from the OMA Browser
#'
#' This function enables to retrieve information on one or several proteins from
#' the OMA Browser database.
#'
#' In its simplest form the function returns the base data of the query protein.
#' The query protein can be selected with any unique id, for example with a
#' UniProtKB accession (P12345), an OMA id (YEAST00012), or a RefSeq id
#' (NP_001226). To retrieve more than one protein, you should pass a vector of
#' IDs.
#'
#' Non-scalar properties of proteins such as their domains, GO annotations,
#' orthologs or homeologs will get loaded upon accessing them, or if you only
#' need this information you can set the attribute parameter to the property
#' name and retrieve this information directly.
#'
#' @seealso For non-unique non-unique IDs or partial ID lookup, use
#'   \code{\link{searchProtein}} instead.
#'
#' @param id Identifier(s) for the entry or entries to be returned. a character
#'   string if single entry or a vector if multiple.
#' @param attribute Instead of the protein, return the attribute property of the
#'   protein. Attriute needs to be one of 'domains', 'orthologs',
#'   'gene_ontology', 'locus', or 'homoeologs'.
#' @return An object containing the JSON keys as attributes or a dataframe
#'   containing the non-scalar protein property.
#' @export
#' @examples
#' getProtein(id='YEAST00001')
#' getProtein(id='YEAST00001', attribute='orthologs')
#' getProtein(id=c('YEAST00001','YEAST00002','YEAST00012'))
#' getProtein(id=c('YEAST00001','YEAST00002','YEAST00012'), attribute='gene_ontology')


getProtein <- function(id, attribute = NULL) {

    if (!is.null(attribute) && !(attribute %in% c("domains", "homeologs", "gene_ontology",
        "orthologs", "locus"))) {
        stop("You must provide a valid attribute.")
    }

    if (length(id) == 1) {
        url <- urlGenerator(endpoint = "protein", id = id, detail = attribute)
    } else if (length(id) > 1) {
        MAXLEN <- 100
        nr_req <- ceiling(length(id)/MAXLEN)
        req_nr <- rep(1:nr_req, each = MAXLEN)[1:length(id)]
        split_ids <- split(id, req_nr)
        body <- lapply(split_ids, FUN = function(x) {
            jsonlite::toJSON(list(ids = x, auto_unbox = TRUE))
        })

        url <- urlGenerator(endpoint = "protein", id = "bulk_retrieve")
        data <- requestFactory(url = url, body = body)
        # make all proteins objects
        data <- lapply(data, FUN = function(prot) {
            n <- names(prot)
            objectFactory(n, prot)
        })
        names(data) <- id

        if (is.null(attribute)) {
            return(data)
        } else {
            attribute_data <- lapply(data, function(x) {
                if (grepl("https://", x[[attribute]])) {
                  requestFactory(x[[attribute]])
                } else {
                  x[[attribute]]
                }
            })

            if (attribute == "locus") {
                # list of g range objects - needs to be merged into a single object
                attribute_data <- suppressWarnings(do.call("c", unlist(attribute_data,
                  use.names = FALSE)))
            } else {
                attribute_data <- plyr::rbind.fill(attribute_data[sapply(attribute_data,
                  function(x) class(x) == "data.frame")])
            }
            return(attribute_data)
        }
    }
    return(requestFactory(url))
}

---
title: "Exploring Hierarchical orthologous groups"
author: "Klara Kaleb"
date: "2017-10-12"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Exploring Hierarchical orthologous groups}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

This little vignette shows you how to get started with the data available for HOGs in the `roma` package.

## The HOGs

Hierarchical orthologous groups (also known as HOGs) are sets of genes that are defined with respect to particular taxonomic ranges of interest[1]. They group genes that have descended from a single common ancestral genes in that taxonomic range. 

HOGs hold a lot of useful information and have many applications in various contexts, including inference of gene function, study of gene evolution dynamics and comparative genomics. Each HOG has a taxonomic range - within it, a given HOG can branch into constructs known as subHOGs which arise in an event of gene duplication.

HOGs can be retrived either by their hog id or by one of their members. Let's say we are interested in a gene that goes by the name of HUMAN22168 - below is the way to access its HOG.

---
title: "Exploring Taxonomic trees with OmaDB"
author: "Klara Kaleb"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Exploring Taxonomic trees with OmaDB}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

Using OmaDB, a user can easily obtain a taxonomic tree of interest using the getTaxonomy structure. The tree can be restricted to a certain root or by a list of members and the data is returned in the newick format. The newick can then be exported and used to create a tree object using ape which can then be visualised using ggtree. 

This is done below using the getTaxonomy(root='Alveolata') function, the output of which is below.


```{r, warning=FALSE, message=FALSE}
library(OmaDB)

load('../data/taxonomy.rda')

getObjectAttributes(taxonomy)


```

The tree can be further analysed and annotated using the ggtree package also available in Bioconductor. This can easily be done using the getTree() function in OmaDB.

---
title: "Sequence Analysis with OmaDB"
author: "Klara Kaleb"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Sequence Mapping with OmaDB}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

Another useful function of the OmaDB package is its functionality to exactly and partially match sequences. We will explore this further in this vignette. 

Let's say we have a sequence of interest that we want to map, in this case:

```{r}
 sequence = "MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHER"
```

We can pass it to the mapSequence() function which returns a list of targets. From this list we can then construct protein objects for which we can obtain further infromation - such as its oma group or its domains. The example response object, generated via mapSequence(sequence), is below.

```{r, warning=FALSE, message=FALSE}
library(OmaDB)

load('../data/sequence_map.rda')

getObjectAttributes(sequence_map)

targets = getAttribute(sequence_map,'targets')

length(targets) 

protein = targets[[1]][['entry_url']]

```

One can also directly obtain GO annotations for a given query sequence (protein$ogene_ontology), which results in an object as below:

```{r, warning=FALSE, message=FALSE}

load('../data/sequence_annotation.rda')

sequence_annotation 

```

---
title: "Get started with OmaDB"
author: "Klara Kaleb"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Get started with OmaDB}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

This little vignette shows you how to get started with the `OmaDB` package. OmaDB is a wrapper for the REST API for the Orthologous MAtrix project (OMA) which is a  database for the inference of orthologs among complete genomes. 

For more details on the OMA project, see https://omabrowser.org/oma/home/.

Note that each function in the package has its own individual documentation, which can be accessed by putting a question mark (?) in front of the function name e.g. ?getProtein() .

## Some useful functions
The package contains a range of functions that are used to query the database in an R friendly way. 
This vignette highlights some of them, whereas some others are described in more detail in other vignettes:

[Exploring Hierarchical orthologous groups with roma](exploring_hogs.html)

[Exploring Taxonomic trees with roma](tree_visualisation.html)

[Sequence Analysis with roma](sequence_mapping.html)

Note that all of the vignettes focus on exploring the example responses generated previously, allowing them to build with or without an internet connection. For each example response, the query that generated it is given. 

### searchProtein

This function searches the OMA database for entries containing the pattern defined and returns the results in a dataframe. Hence, it is usually a good starting place. Example response, generated via searchProtein('MAL'), is below.

```{r, warning=FALSE, message=FALSE}
library(OmaDB)

xref = load('../data/xref.rda')

head(xref)

```

### getGenomePairs

This function serves to obtain the orthologs for 2 whole genomes. The result is a dataframe containing information on each member in the pair and their relationship. Below is the representation of the example response, generated using getGenomePairs('YEAST','ASHGO').

```{r, warning=FALSE, message=FALSE}

load('../data/pairs.rda')

head(pairs)

```

### getProtein

This function serves to obtain the information for either a single protein entry or multiple protein entries in a database. For more info, see ?getProtein(). There are similar functions to obtain information on genomes, OMA groups and HOGs i.e. getGenome(), getOMAGroup() and getHOG() respectively. 

### getObjectAttributes

Single entries in the database are represented as S3 objects, with their attributes corresponding to the information requested. These attributes vary greatly from object to object, and the helper function getObjectAttributes() allows the user to list all the object attributes and their corresponding data types. 

### getAttribute

The specific attributes of the created object can be accessed via $ or via the getAttribute() function. Below is an example of object containing information about an OMA group. 

Below is the exploration of the example OMA group entry response, obtained via getOMAGroup('737636').

```{r, warning=FALSE, message=FALSE}

load('../data/group.rda')

object_attributes = getObjectAttributes(group)

group$fingerprint

getAttribute(group, 'fingerprint')


```

### lazy loading

In most cases there is great quantity of information available for a given entry and this impacts the data retrival time. Due to this, the information available for such entries is split into a number of endpoints and these are included appropriatelly as redirects in URL form. These are automatically loaded upon $ or getAttribute() accession. 


For further information on the OMA REST API please visit [OMA REST API DOCUMENTATION](http://omadev.cs.ucl.ac.uk/api/docs).

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getVersion.R
\name{getVersion}
\alias{getVersion}
\title{Get the API and database version function}
\usage{
getVersion()
}
\value{
S3 object
}
\description{
The function to obtain the API and database version that the package is using.
}
\examples{
getVersion()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getGenome.R
\name{getGenome}
\alias{getGenome}
\title{Retrieve a genome from the OMA Browser database}
\usage{
getGenome(id = NULL, attribute = NULL)
}
\arguments{
\item{id}{A genome identifier. By default, all available genomes will be returned.}

\item{attribute}{An extra attribute to be returned (proteins)}
}
\value{
an object containing the JSON keys as attributes or a dataframe
}
\description{
This function obtains the basic information for one specific genome available
on the OMA Browser, or - if no id is provided - a dataframe with all available
genomes.
}
\details{
Ids can be either the scientific name of a species, the NCBI taxonomy id or
the UniProtKB mnemonic species code.

The optional argument attribute can be used to directly load the proteins
belonging to the genome. Alternatively, you can access the proteins attribute
of the result which will transparently load the proteins from the OMA Browser.
}
\examples{
getGenome()
getGenome(id='HUMAN')
getGenome(id=9606)
getGenome(id='HUMAN',attribute='proteins')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{sequence_map}
\alias{sequence_map}
\title{An example dataframe containing proteins identified from a given sequence.}
\format{A dataframe with 3 variables:
\describe{
  \item{query}{sequence that was queried}
  \item{identified_by}{type of identification}
  \item{targets}{list of protein targets identified}
  ...
}}
\source{
\url{https://omabrowser.org/api/sequences/?query=MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHER}
}
\usage{
sequence_map
}
\description{
An example dataframe containing proteins identified from a given sequence.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/obsolete.R
\name{getGenomeAlignment-deprecated}
\alias{getGenomeAlignment-deprecated}
\title{Get Whole Genome Alignment Function}
\usage{
getGenomeAlignment(genome1, genome2, chr1 = NULL, chr2 = NULL,
  rel_type = NULL)
}
\arguments{
\item{genome_id1}{an identifier for the first genome, which can be either its taxon id or UniProt species code}

\item{genome_id2}{an an identifier for the second genome, which can be either its taxon id or UniProt species code}

\item{chr1}{the chromosome of interest for the first genome}

\item{chr2}{the chromosome of interest for the second genome}

\item{rel_type}{the pairs relationship type}

\item{per_page}{the number of instances to be returned or 'all'. default is set to a 100.}
}
\value{
a dataframe containing information about both the entries in the orthologous pair and their relationship
}
\description{
This function should no longer be used. Use instaed \code{\link{getGenomePairs}}.
}
\seealso{
\code{\link{OmaDB-deprecated}}
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{sequence_annotation}
\alias{sequence_annotation}
\title{An example dataframe containing GO annotations identified from a given sequence.}
\format{A dataframe with 13 variables:
\describe{
  \item{Qualifier}{qualifier of the annotation}
  \item{GO_ID}{GO term for the annotation}
  \item{With}{GO term for the annotation}
  \item{Evidence}{evidence for the annotation}
  \item{Date}{date}
  \item{DB_Object_Type}{identified object type}
  \item{DB_Object_Name}{identified object name}
  \item{Aspect}{aspect}
  \item{Assigned_By}{assignment of the annotation}
  \item{GO_name}{GO term name}
  \item{DB}{database}
  \item{DB.Reference}{database reference}
  \item{Synonym}{synonym}
  ...
}}
\source{
\url{https://omabrowser.org/api/function/?query=MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHER}
}
\usage{
sequence_annotation
}
\description{
An example dataframe containing GO annotations identified from a given sequence.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/obsolete.R
\name{getAnnotation-deprecated}
\alias{getAnnotation-deprecated}
\title{Get GO annotation for a sequence Function}
\usage{
getAnnotation(query)
}
\arguments{
\item{query}{the sequence to be annotated, it can be either a string or an AAString object from the Biostrings package}
}
\value{
a data.frame containg the GO annotaition information linked to the query sequence
}
\description{
This function should no longer be used. Use instead \code{\link{annotateSequence}}.
}
\seealso{
\code{\link{OmaDB-deprecated}}
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getGenomePairs.R
\name{getGenomePairs}
\alias{getGenomePairs}
\title{Retrieves the pairwise relations among two genomes}
\usage{
getGenomePairs(genome_id1, genome_id2, chr1 = NULL, chr2 = NULL,
  rel_type = NULL, ...)
}
\arguments{
\item{genome_id1}{an identifier for the first genome, which can be either its taxon id or UniProt species code}

\item{genome_id2}{an an identifier for the second genome, which can be either its taxon id or UniProt species code}

\item{chr1}{the chromosome of interest for the first genome}

\item{chr2}{the chromosome of interest for the second genome}

\item{rel_type}{the pairs relationship type}

\item{...}{qwargs}
}
\value{
a dataframe containing information about both the entries in the orthologous pair and their relationship
}
\description{
This function retrieves the pairwise relations among two genomes from
the OMA Browser database. The relations are orthologs in case the 
genomes are different and "close paralogs" and "homoeologs" in case 
they are the same.
}
\details{
By using the parameters chr1 and chr2, one can limit the relations 
to a certain chromosome for one or both genomes. The id of the 
chromosome corresponds to the chromosome ids from the 
\code{\link{getGenome}} result.

The rel_type parameter further limits the returned relations to a
specific subtype of orthologs (i.e. "1:1", "1:n", "m:1", "m:n") or 
- within a genome to either "close paralogs" or "homeologs".
}
\examples{
getGenomePairs(genome_id1='YEAST',genome_id2='ASHGO')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getOMAGroup.R
\name{getOMAGroup}
\alias{getOMAGroup}
\title{Retrieve an OMA Group from the OMA Browser}
\usage{
getOMAGroup(id, attribute = NULL)
}
\arguments{
\item{id}{An identifier for the group. See above for possible types of IDs.}

\item{attribute}{an extra attribute to be returned (close_groups)}
}
\value{
an object containing the JSON keys as attributes or a dataframe
}
\description{
This function obtains an OMA Group from the OMA Browser database. An OMA Group
is defined to be a clique of proteins that are all orthologous to each other,
i.e. they are all related through speciation events only. An OMA Group can thus
by definition not contain any inparalogs. It is a very stringent orthology
grouping approach.
OMA Groups are mostly useful to infer phylogenetic species tree where they
can be used as marker genes.
}
\details{
Retrieving an OMA Group can be done using a group nr as id, its fingerprint
(a 7mer AA sequence which is unique to proteins in that group), a member
protein id or any sequence pattern that is unique to the group.
}
\examples{
getOMAGroup(id='58')
getOMAGroup(id='P12345')
getOMAGroup(id='NNRRGRI')
getOMAGroup(id='58', attribute='close_groups')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{taxonomy}
\alias{taxonomy}
\title{An example newick format taxonomy object.}
\format{An S3 with 2 variables:
\describe{
  \item{root_taxon}{sequence that was queried}
  \item{newick}{taxonomy newick}
  ...
}}
\source{
\url{https://omabrowser.org/api/taxonomy/Alveolata/?type=newick}
}
\usage{
taxonomy
}
\description{
An example newick format taxonomy object.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getHOG.R
\name{getHOG}
\alias{getHOG}
\title{Retrieve a HOG from the OMA Browser}
\usage{
getHOG(id, level = NULL, members = FALSE)
}
\arguments{
\item{id}{an identifier for the HOG to be returned - either its HOG ID or a protein id.}

\item{level}{a specific level for the HOG to be restricted to. level can either be 'root', or the name of a taxonomic level that is part of the HOG, e.g. 'Fungi'. By default it will retrieve the depest level of the most specific subhog for the given ID.}

\item{members}{boolean that when set to TRUE returns a dataframe containg the protein members at a given hog level}
}
\value{
an object containing HOG attributes, or a list of those
}
\description{
The function retrieves a specific Hierarchical Orthologous Group (HOG) from
the OMA Browser database. A HOG is a set of genes that have all decendet from
a single ancestral gene at a specific taxonomic level.
}
\details{
A HOG can be identified by its member proteins and a taxonomic level, or
a HOG ID. As a taxonomic level, you can use either 'root' to retrieve the
HOG at its deepest level, or the name of NCBI taxonomy level, or leave it
out in which case the deepest level that doesn't include a duplication node
is used.

The function either returns a single hog object or a list of hog
objects. The later happens if the HOG ID you provide has already split into
several sub-hogs at the level you indicate.
}
\examples{
getHOG(id = 'YEAST590')
getHOG(id = 'YEAST590', level='root')
getHOG(id = 'YEAST590', level='Saccharomycetaceae', members=TRUE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{xref}
\alias{xref}
\title{An example xref object.}
\format{A dataframe with 8 variables:
\describe{
  \item{xref}{cross reference}
  \item{source}{source of the cross reference}
  \item{entry_nr}{oma database entry number}
  \item{oma_id}{oma id of the cross reference}
  \item{genome.code}{genome_id of the cross reference}
  \item{genome.taxon_id}{taxon_id of the cross reference}
  \item{genome.species}{species of the cross reference}
  \item{genome.genome_url}{genome url pointer of the cross reference}
  ...
}}
\source{
\url{https://omabrowser.org/api/xref/?search=MAL}
}
\usage{
xref
}
\description{
An example xref object.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getTree.R
\name{getTree}
\alias{getTree}
\title{Get the Tree Object}
\usage{
getTree(newick)
}
\arguments{
\item{newick}{The newick tree to be instantiated.}
}
\value{
a tree object
}
\description{
A convenience function to obtain a tree object from newick tree,
essentially wraps read.tree from the ape package.
}
\examples{
taxonomy = getTaxonomy(root='Alveolata')
getTree(newick=taxonomy$newick)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/obsolete.R
\name{getData-deprecated}
\alias{getData-deprecated}
\title{Get the Data Function}
\usage{
getData(type, id, attribute = NULL)
}
\arguments{
\item{type}{the type for the entry to be returned - either protein, genome or group}

\item{id}{an identifier for the entry to be returned. For more information, see the 'Get started with OmaDB' vignette.}

\item{attribute}{an extra attribute}
}
\value{
an object containing the JSON keys as attributes
}
\description{
The function to obtain the information available for a single entry in the datase.
This function should no longer be used. It has been divided into several functions:
Use the following functions instead.
\itemize{
  \item \code{\link{getProtein}} to obtain proteins (former \code{type='protein'})
  \item \code{\link{getGenome}} to obtain genomes (former \code{type='genome'})
  \item \code{\link{getOMAGroup}} to obtain genomes (former \code{type='group'})
}
}
\seealso{
\code{\link{OmaDB-deprecated}}
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/formatTopGO.R
\name{formatTopGO}
\alias{formatTopGO}
\title{Format the GO annotations data}
\usage{
formatTopGO(geneList, format)
}
\arguments{
\item{geneList}{the list of OmaDB protein objects or a dataframe of ontologies to be included in the analysis - this is where the GO annotations are extracted from.}

\item{format}{format for the data to be returned in - either 'GO2geneID' or 'geneID2GO'}
}
\value{
a list containing the GO2geneID or geneID2GO information
}
\description{
The function to create a list of GO annotations that is compatible with topGO from protein objects in roma
}
\examples{
geneList = list(getProtein(id='YEAST01'),getProtein(id='YEAST03'))
annotations = formatTopGO(geneList,format='geneID2GO')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/OmaDBObject.R
\name{getAttribute}
\alias{getAttribute}
\title{Get the value for the Object Attribute}
\usage{
getAttribute(obj, attribute)
}
\arguments{
\item{obj}{the object of interest}

\item{attribute}{the attribute of interest}
}
\value{
an value for a given object attribute
}
\description{
The function to obtain the value for an object attribute.
}
\examples{
members = getAttribute(getOMAGroup(id ='YEAST58'),'members')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{pairs}
\alias{pairs}
\title{An example genome alignment object.}
\format{A dataframe object with 12 variables for each member of the pair, as well some 3 additional variables:
\describe{
  \item{entry_nr}{entry number of the ortholog}
  \item{omaid}{oma identifier of the ortholog}
  \item{canonicalid}{canonicalid of the ortholog}
  \item{sequence_md5}{sequence_md5 of the ortholog}
  \item{oma_group}{oma_group of the ortholog}
  \item{oma_hog_id}{hog id of the ortholog}
  \item{chromosome}{chromosomal location of the ortholog}
  \item{locus.start}{start locus of the ortholog}
  \item{locus.end}{end locus of the ortholog}
  \item{locus.strand}{locus strand of the ortholog}
  \item{is_main_isoform}{true/false}
  \item{rel_type}{relationship type of the ortholog to the gene}
  \item{distance}{ortholog distance}
  \item{score}{ortholog score}
  ...
}}
\source{
\url{https://omabrowser.org/api/pairs/YEAST/ASHGO/}
}
\usage{
pairs
}
\description{
A dataframe containing information for the whole genome aligment of YEAST and ASHGO.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{group}
\alias{group}
\title{An example OMA group object.}
\format{An S3 object with 4 variables:
\describe{
  \item{group_nr}{group number, not stable across releases}
  \item{fingerprint}{fingerprint of the oma group, stable across releases}
  \item{related_groups}{url to the endpoint containing the list of oma groups that share some of the orthologs with this oma group}
  \item{members}{list of protein members of this oma group}
  ...
}}
\source{
\url{https://omabrowser.org/api/group/YEAST58/}
}
\usage{
group
}
\description{
An object containing information for the OMA group number 737636.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/obsolete.R
\name{getXref-deprecated}
\alias{getXref-deprecated}
\title{Get the CrossReferences in the OMA database for a pattern}
\usage{
getXref(pattern)
}
\arguments{
\item{pattern}{the pattern to query the OMA database with - needs to be at least 3 characters long}
}
\value{
a data.frame containing information on the cross references for a given pattern
}
\description{
This function is should no longer be used. Use instead \code{\link{searchProtein}}.
}
\seealso{
\code{\link{OmaDB-deprecated}}
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{setAPI}
\alias{setAPI}
\title{Set the url to the OMA Browser API}
\usage{
setAPI(url)
}
\arguments{
\item{url}{Base url to the API}
}
\description{
Function to set the base url to the OMA Browser API. If no url is
specified, the default OMA Browser API url is used.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{protein}
\alias{protein}
\title{An example protein object.}
\format{A S3 object with 23 variables:
\describe{
  \item{entry_nr}{entry number of the protein}
  \item{entry_url}{url pointer to the protein}
  \item{omaid}{oma identifier of the protein}
  \item{canonicalid}{canonicalid of the protein}
  \item{sequence_md5}{sequence_md5 of the protein}
  \item{oma_group}{oma_group of the protein}
  \item{oma_hog_id}{hog id of the protein}
  \item{chromosome}{chromosomal location of the protein}
  \item{locus}{GRanges object with the locus information for the protein}
  \item{is_main_isoform}{true/false}
  \item{roothog_id}{root taxonomic level of the relevant hog}
  \item{roothog_id}{taxonomic levels of the hog in which the protein is present}
  \item{sequence_length}{length of the protein sequence}
  \item{sequence}{AAString of the protein sequence}
  \item{cdna}{DNAString of the protein sequence}
  \item{domains}{url pointer to the list of protein domains}
  \item{xref}{url pointer to the list of protein cross references}
  \item{orthologs}{url pointer to the list of protein orthologs}
  \item{homeologs}{url pointer to the list of protein homeologs}
  \item{gene_ontology}{url pointer to the list of protein GO ontologies}
  \item{oma_group_url}{url pointer to the protein oma group}
  \item{oma_hog_members}{url pointer to the protein hog members}
  \item{alternative_isoforms_urls}{list of url pointers to the protein isoforms}
  ...
}}
\source{
\url{https://omabrowser.org/api/protein/6633022/}
}
\usage{
protein
}
\description{
An object containing information for the YEAST00058 protein.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getTopGO.R
\name{getTopGO}
\alias{getTopGO}
\title{Get the topGO Object function}
\usage{
getTopGO(annotations, format, foregroundGenes, ontology)
}
\arguments{
\item{annotations}{list of GO annoatations obtained from the formatTopGO()}

\item{format}{Format for the data to be returned in - either 'GO2geneID' or 'geneID2GO'}

\item{foregroundGenes}{List of identifiers for the foreground genes}

\item{ontology}{The ontology for which the enrichment should be done. This
parameter is passed directly to the topGOdata constructor.}
}
\value{
topGO object
}
\description{
The function to create a topGO object containing the GO annotations for the given protein list.
}
\examples{
geneList = list(getProtein(id='YEAST58'),getProtein(id='YEAST00059'))
annotations = formatTopGO(geneList,format='geneID2GO')
library(topGO)
getTopGO(annotations, foregroundGenes = list('YEAST00058'), format = 'geneID2GO', ontology = 'BP')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getLocus.R
\name{getLocus}
\alias{getLocus}
\title{Get loci for a given list of proteins}
\usage{
getLocus(proteins)
}
\arguments{
\item{proteins}{the dataframe or a list of dataframes containing the protein data of interest. this can either be the members df or a list of protein ids.}
}
\value{
genomic range object from the GenomicRanges package in Bioconductor
}
\description{
Function to obtain loci in genomic range format for a given list of proteins
}
\examples{
loci = getLocus(proteins = getOMAGroup('YEAST58')['members'])
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{$.omadb_obj}
\alias{$.omadb_obj}
\title{Resolve URLs automatically when accessed}
\usage{
\method{$}{omadb_obj}(x, name)
}
\arguments{
\item{x}{object}

\item{name}{attribute}
}
\value{
API response behind the URL
}
\description{
The function to obtain further information from a given url.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{hog}
\alias{hog}
\title{An example HOG object.}
\format{An S3 object with 8 variables:
\describe{
  \item{hog_id}{hog identifier}
  \item{level}{the taxonomic level of this hog}
  \item{levels_url}{url pointer to the hog information at a given level}
  \item{members_url}{url pointer to the list of gene members for this hog}
  \item{alternative_members}{a dataframe object containing the rest of the taxonomic levels in this hog}
  \item{roothog_id}{the root taxonomic level of this hog}
  \item{parent_hogs}{a dataframe containing information on the parent hogs to the current hogs}
  \item{children_hogs}{a dataframe containing information on the children hogs to the current hogs}
  ...
}}
\source{
\url{https://omabrowser.org/api/hog/HOG:0273533.1b/}
}
\usage{
hog
}
\description{
An object containing information for the HOG:0273533.1b.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/annotateSequence.R
\name{annotateSequence}
\alias{annotateSequence}
\title{Map GO annotation to a sequence that is not available in the OMA Browser}
\usage{
annotateSequence(query)
}
\arguments{
\item{query}{the sequence to be annotated, it can be either a string or an
AAString object from the Biostrings package}
}
\value{
a data.frame containing the the GO annotation information of the
       most similar protein to the query sequence
}
\description{
This function obtain Gene Ontology annotation for a given sequence that
does not need to exist in the OMA Browser so far. The query sequence will
analysed and a fast homology detection approach based on kmers will be used
to detect the closest sequences in OMA. GO annotations for these top hits
will be used to annotated the query sequence.
}
\examples{
annotateSequence(query='MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHERRFIEINTDGEPQREYDSLQQSTEHLATDLAKRTFTVLSYNTLCQHYATPKMYRYTPSWALSWDYRRNKLKEQILSYDSDLLCLQEVESKTFEEYWVPLLDKHGYTGIFHAKARAKTMHSKDSKKVDGCCIFFKRDQFKLITKDAMDFSGAWMKHKKFQRTEDYLNRAMNKDNVALFLKLQHIPSGDTIWAVTTHLHWDPKFNDVKTFQVGVLLDHLETLLKEETSHNFRQDIKKFPVLICGDFNSYINSAVYELINTGRVQIHQEGNGRDFGYMSEKNFSHNLALKSSYNCIGELPFTNFTPSFTDVIDYIWFSTHALRVRGLLGEVDPEYVSKFIGFPNDKFPSDHIPLLARFEFMKTNTGSKKV')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/OmaDB.R
\docType{package}
\name{OmaDB-package}
\alias{OmaDB}
\alias{OmaDB-package}
\title{OmaDB: A package for the orthology prediction data download from OMA database.}
\description{
OmaDB is a wrapper for the REST API for the Orthologous MAtrix project (OMA)
which is a  database for the inference of orthologs among complete genomes.
For more details on the OMA project, see \url{https://omabrowser.org/}.
}
\section{OmaDB functions}{

The package contains a range of functions that are used to query the
database. Some of the main functions are listed below:

\itemize{
  \item getProtein()
  \item getHOG()
  \item getOMAGroup()
  \item getGenomePairs()
  \item getTaxonomy()
  \item mapSequence()
  \item annotateSequence()
  \item searchProtein()
}

In addition to these, OmaDB features a range of functions that are used to
format the retrieved data into some commonly used Bioconductor objects using
packages such as GenomicRanges, Biostrings, topGO and ggtree. Some of them
are listed below:

\itemize{
  \item formatTopGO()
  \item getGRanges()
}

The above functions are described in more detail in the package vignette's
listed below:


\itemize{
  \item Get started with OmaDB
  \item Exploring Hierarchical orthologous groups with OmaDB
  \item Exploring Taxonomic trees with OmaDB
  \item Sequence Analysis with OmaDB
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/obsolete.R
\name{OmaDB-deprecated}
\alias{OmaDB-deprecated}
\alias{getXref}
\alias{getAnnotation}
\alias{getGenomeAlignment}
\alias{getData}
\title{Deprecated functions in package \pkg{OmaDB}.}
\usage{
getXref(pattern)

getAnnotation(query)

getGenomeAlignment(genome1, genome2, chr1 = NULL, chr2 = NULL,
  rel_type = NULL)

getData(type, id, attribute = NULL)
}
\description{
These functions are provided for compatibility with
older versions of \pkg{OmaDB} only, and will be defunct at the
next release.
}
\details{
The following functions are deprecated and will be
made defunct; use the replacement indicated below:
}
\section{\code{getXref}}{

For \code{getXref}, use \code{\link{searchProtein}}.
}

\section{\code{getAnnotation}}{

For \code{getAnnotation}, use \code{\link{annotateSequence}}.
}

\section{\code{getGenomeAlignment}}{

For \code{getGenomeAlignment}, use \code{\link{getGenomePairs}}.
}

\section{\code{getData}}{

For \code{getData}, use \code{\link{getProtein}, \link{getGenome}, \link{getOMAGroup}}.
}

\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{resolveURL}
\alias{resolveURL}
\title{Load data for a given url from the OMA Browser API.}
\usage{
resolveURL(url)
}
\arguments{
\item{url}{The url of interest}
}
\value{
a data.frame containing the information behind an URL
}
\description{
This function is usualy not needed by users. In most circumstances
an attribute containing a URL is automatically loaded when accessed.
However, in case the data is transformed into a dataframe, this will
no longer be true, in which case one can access the data behind this
attribute using this function.
}
\examples{
resolveURL('http://omabrowser.org/api/protein/YEAST58/gene_ontology/')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getTaxonomy.R
\name{getTaxonomy}
\alias{getTaxonomy}
\title{Get the Taxonomic tree function}
\usage{
getTaxonomy(root = NULL, members = NULL, newick = TRUE)
}
\arguments{
\item{root}{optional parameter, the root of the node of interest}

\item{members}{optional parameter, list of member ncbi taxon or UniProt IDs that should be included in the induced taxonomy.}

\item{newick}{optional parameter, boolean default set to TRUE}
}
\value{
an object containing the JSON keys as attributes
}
\description{
The function to obtain the taxonomic tree from the database in the newick format that can be plugged into phylo.io for visualisation.
}
\examples{
getTaxonomy()
getTaxonomy(members='YEAST,ASHGO')
getTaxonomy(root='Alveolata')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{orthologs}
\alias{orthologs}
\title{An example orthologs object.}
\format{A dataframe object with 15 variables:
\describe{
  \item{entry_nr}{entry number of the ortholog}
  \item{omaid}{oma identifier of the ortholog}
  \item{canonicalid}{canonicalid of the ortholog}
  \item{sequence_md5}{sequence_md5 of the ortholog}
  \item{oma_group}{oma_group of the ortholog}
  \item{oma_hog_id}{hog id of the ortholog}
  \item{chromosome}{chromosomal location of the ortholog}
  \item{locus.start}{start locus of the ortholog}
  \item{locus.end}{end locus of the ortholog}
  \item{locus.strand}{locus strand of the ortholog}
  \item{is_main_isoform}{true/false}
  \item{rel_type}{relationship type of the ortholog to the gene}
  \item{distance}{ortholog distance}
  \item{score}{ortholog score}
  ...
}}
\source{
\url{https://omabrowser.org/api/protein/YEAST00058/orthologs}
}
\usage{
orthologs
}
\description{
A dataframe containing information for the orthologs of protein YEAST00058.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/OmaDBObject.R
\name{getObjectAttributes}
\alias{getObjectAttributes}
\title{Get the Object Attributes}
\usage{
getObjectAttributes(obj)
}
\arguments{
\item{obj}{the object of interest}
}
\value{
an list of object attributes and their data classes
}
\description{
The function to obtain the attributes and their data types for the object created.
}
\examples{
attributes = getObjectAttributes(getOMAGroup(id ='YEAST58'))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/searchProtein.R
\name{searchProtein}
\alias{searchProtein}
\title{Get the CrossReferences in the OMA database for a pattern}
\usage{
searchProtein(pattern)
}
\arguments{
\item{pattern}{the pattern to query the OMA database with - needs to be at least 3 characters long}
}
\value{
a data.frame containing information on the cross references for a given pattern
}
\description{
The function to list all the crossreferences that match a certain defined pattern.
}
\examples{
searchProtein(pattern='MAL')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getProtein.R
\name{getProtein}
\alias{getProtein}
\title{Retrieve a protein from the OMA Browser}
\usage{
getProtein(id, attribute = NULL)
}
\arguments{
\item{id}{Identifier(s) for the entry or entries to be returned. a character
string if single entry or a vector if multiple.}

\item{attribute}{Instead of the protein, return the attribute property of the
protein. Attriute needs to be one of 'domains', 'orthologs',
'gene_ontology', 'locus', or 'homoeologs'.}
}
\value{
An object containing the JSON keys as attributes or a dataframe
  containing the non-scalar protein property.
}
\description{
This function enables to retrieve information on one or several proteins from
the OMA Browser database.
}
\details{
In its simplest form the function returns the base data of the query protein.
The query protein can be selected with any unique id, for example with a
UniProtKB accession (P12345), an OMA id (YEAST00012), or a RefSeq id
(NP_001226). To retrieve more than one protein, you should pass a vector of
IDs.

Non-scalar properties of proteins such as their domains, GO annotations,
orthologs or homeologs will get loaded upon accessing them, or if you only
need this information you can set the attribute parameter to the property
name and retrieve this information directly.
}
\examples{
getProtein(id='YEAST00001')
getProtein(id='YEAST00001', attribute='orthologs')
getProtein(id=c('YEAST00001','YEAST00002','YEAST00012'))
getProtein(id=c('YEAST00001','YEAST00002','YEAST00012'), attribute='gene_ontology')
}
\seealso{
For non-unique non-unique IDs or partial ID lookup, use
  \code{\link{searchProtein}} instead.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mapSequence.R
\name{mapSequence}
\alias{mapSequence}
\title{Map the Protein Sequence Function}
\usage{
mapSequence(query, search = NULL, full_length = FALSE)
}
\arguments{
\item{query}{the sequence to be searched, it can be either a string or an AAString object from the Biostrings package}

\item{search}{argument to choose search strategy. Can be set to 'exact', 'approximate' or 'mixed'. Defaults to 'mixed', meaning first tries to find exact match. If no target can be found, uses approximate search strategy to identify query sequence in database.}

\item{full_length}{a boolean indicating whether or not for exact matches, the query sequence must be matching the full target sequence. By default, a partial exact match is also reported as exact match.}
}
\value{
a data.frame containing the information of matches for the query sequence
}
\description{
The function to identify a sequence.
}
\examples{
mapSequence(query='MNDPSLLGYPNVGPQQQQQQQQQQHAGLLGKGTPNALQQQLHMNQLTGIPPPGLMNNSDVHTSSNNNSRQLLDQLANGNANMLNMNMDNNNNNNNNNNNNNNNGGGSGVMMNASTAAVNSIGMVPTVGTPVNINVNASNPLLHPHLDDPSLLNNPIWKLQLHLAAVSAQSLGQPNIYARQNAMKKYLATQQAQQAQQQAQQQAQQQVPGPFGPGPQAAPPALQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHERRFIEINTDGEPQREYDSLQQSTEHLATDLAKRTFTVLSYNTLCQHYATPKMYRYTPSWALSWDYRRNKLKEQILSYDSDLLCLQEVESKTFEEYWVPLLDKHGYTGIFHAKARAKTMHSKDSKKVDGCCIFFKRDQFKLITKDAMDFSGAWMKHKKFQRTEDYLNRAMNKDNVALFLKLQHIPSGDTIWAVTTHLHWDPKFNDVKTFQVGVLLDHLETLLKEETSHNFRQDIKKFPVLICGDFNSYINSAVYELINTGRVQIHQEGNGRDFGYMSEKNFSHNLALKSSYNCIGELPFTNFTPSFTDVIDYIWFSTHALRVRGLLGEVDPEYVSKFIGFPNDKFPSDHIPLLARFEFMKTNTGSKKV')
mapSequence(search='mixed',query='NKLLQPTDFQQSHIAEASKSLVDCTKQALMEMADTLTDSKTAKKQQPTGDSTPSGTATNSAVSTPLTPKIELFANGKDEANQALLQHKKLSQYSIDEDDDIENRMVMPKDSKYDDQLWHALDLSNLQIFNISANIFKYDFLTRLYLNGNSLTELPAEIKNLSNLRVLDLSHNRLTSLPAELGSCFQLKYFYFFDNMVTTLPWEFGNLCNLQFLGVEGNPLEKQFLKILTEKSVTGLIFYLRDNRPEIPLPHERRFIEINTDGEPQREYDSLQQSTEHLATDLAKRTFTVLSYNTLCQHYATPKMYRYTPSWALSWDYRRNKLKEQILSYDSDLLCLQEVESKTFEEYWVPLLDKHGYTGIFHAKARAKTMHSKDSKKVDGCCIFFKRDQFKLITKDAMDFSGAWMKHKKFQRTEDYLNRAMNKDNVALFLKLQHIPSGDTIWAVTTHLHWDPKFNDVKTFQVGVLLDHLETLLKEETSHNFRQDIKKFPVLICGDFNSYINSAVYELINTGRVQIHQEGNGRDFGYMSEKNFSHNLALKSSYNCIGELPFTNFTPSFTDVIDYIWFSTHALRVRGLLGEVDPEYVSKFIGFPNDKFPSDHIPLLARFEFMKTNTGSKKV')
}
